==> haskell-tasty-smallcheck-0.8.1-40-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tasty-smallcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty-smallcheck
version: 0.8.1
id: tasty-smallcheck-0.8.1-3QDQkZQT1X1BN7fmorLbrI
key: tasty-smallcheck-0.8.1-3QDQkZQT1X1BN7fmorLbrI
license: MIT
maintainer: Roman Cheplyaka <roma@ro-che.info>
author: Roman Cheplyaka <roma@ro-che.info>
homepage: http://documentup.com/feuerbach/tasty
synopsis: SmallCheck support for the Tasty test framework.
description:
    SmallCheck support for the Tasty test framework.
category: Testing
abi: 2f4a0e374a04b8b7a7e74b5d98c215c6
exposed: True
exposed-modules:
    Test.Tasty.SmallCheck
import-dirs: /usr/lib/ghc-8.6.5/site-local/tasty-smallcheck-0.8.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/tasty-smallcheck-0.8.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/tasty-smallcheck-0.8.1
hs-libraries: HStasty-smallcheck-0.8.1-3QDQkZQT1X1BN7fmorLbrI
depends:
    async-2.2.2-5KbUJa8fnnu9oaTmXcEjsG base-4.12.0.0
    smallcheck-1.1.5-IcJgcWLNXQN4xE4F00EnpE
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP
    tasty-1.2-L0qrhWDKU2n6IIJu4C6GSU
haddock-interfaces: /usr/share/doc/haskell-tasty-smallcheck/html/tasty-smallcheck.haddock
haddock-html: /usr/share/doc/haskell-tasty-smallcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-smallcheck-0.8.1-41-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tasty-smallcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty-smallcheck
version: 0.8.1
id: tasty-smallcheck-0.8.1-5gxgo6DfO147XSAgXCTAY7
key: tasty-smallcheck-0.8.1-5gxgo6DfO147XSAgXCTAY7
license: MIT
maintainer: Roman Cheplyaka <roma@ro-che.info>
author: Roman Cheplyaka <roma@ro-che.info>
homepage: http://documentup.com/feuerbach/tasty
synopsis: SmallCheck support for the Tasty test framework.
description:
    SmallCheck support for the Tasty test framework.
category: Testing
abi: d3734b00929afeeb52163a3dd5633799
exposed: True
exposed-modules:
    Test.Tasty.SmallCheck
import-dirs: /usr/lib/ghc-8.6.5/site-local/tasty-smallcheck-0.8.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/tasty-smallcheck-0.8.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/tasty-smallcheck-0.8.1
hs-libraries: HStasty-smallcheck-0.8.1-5gxgo6DfO147XSAgXCTAY7
depends:
    async-2.2.2-5KbUJa8fnnu9oaTmXcEjsG base-4.12.0.0
    smallcheck-1.1.5-IcJgcWLNXQN4xE4F00EnpE
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP
    tasty-1.2.3-AUVOTgx4uuy2lCe0MDaZEJ
haddock-interfaces: /usr/share/doc/haskell-tasty-smallcheck/html/tasty-smallcheck.haddock
haddock-html: /usr/share/doc/haskell-tasty-smallcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
